/*
 * Copyright 2009 University Corporation for Advanced Internet Development, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.ws.wssecurity;

import java.util.List;

import javax.xml.namespace.QName;

/**
 * Interface for element having a <code>@wsse:Usage</code> attribute.
 */
public interface UsageBearing {
    
    /** The wsse:@Usage attribute local name. */
    public static final String WSSE_USAGE_ATTR_LOCAL_NAME = "Usage";

    /** The wsse:@Usage qualified attribute name. */
    public static final QName WSSE_USAGE_ATTR_NAME =
        new QName(WSSecurityConstants.WSSE_NS, WSSE_USAGE_ATTR_LOCAL_NAME, WSSecurityConstants.WSSE_PREFIX);

    /**
     * Returns the list of <code>wsse:@Usage</code> attributes value.
     * 
     * @return the list of attribute values
     */
    public List<String> getWSSEUsages();

    /**
     * Sets the list of <code>wsse:@Usage</code> attributes value.
     * 
     * @param usages the list of attribute values
     */
    public void setWSSEUsages(List<String> usages);
    
}
